Hello community,
here is the log from the commit of package perl-Bootloader
checked in at Wed Sep 19 19:15:47 CEST 2007.
--------
--- perl-Bootloader/perl-Bootloader.changes 2007-09-18 10:14:20.000000000 +0200
+++ /mounts/work_src_done/STABLE/perl-Bootloader/perl-Bootloader.changes 2007-09-18 21:00:22.000000000 +0200
@@ -1,0 +2,21 @@
+Tue Sep 18 20:56:03 CEST 2007 - aosthof(a)suse.de
+
+- Added more verbose logging to update-bootloader and
+ bootloader_entry to be able to better analyze occurring
+ problems (#309837)
+
+-------------------------------------------------------------------
+Tue Sep 18 20:35:18 CEST 2007 - od(a)suse.de
+
+- Add comment for former default value only during update (related
+ to #309837, prevents accumulating wrong information that may be
+ used during a later update)
+- Version bump to 0.4.29
+
+-------------------------------------------------------------------
+Tue Sep 18 14:11:17 CEST 2007 - aosthof(a)suse.de
+
+- Adapted timestamps for log files (#309837)
+- Version bump to 0.4.28
+
+-------------------------------------------------------------------
Old:
----
perl-Bootloader-0.4.27.tar.bz2
New:
----
perl-Bootloader-0.4.29.tar.bz2
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Other differences:
------------------
++++++ perl-Bootloader.spec ++++++
--- /var/tmp/diff_new_pack.Xy8879/_old 2007-09-19 19:15:23.000000000 +0200
+++ /var/tmp/diff_new_pack.Xy8879/_new 2007-09-19 19:15:23.000000000 +0200
@@ -1,5 +1,5 @@
#
-# spec file for package perl-Bootloader (Version 0.4.27)
+# spec file for package perl-Bootloader (Version 0.4.29)
#
# Copyright (c) 2007 SUSE LINUX Products GmbH, Nuernberg, Germany.
# This file and all modifications and additions to the pristine
@@ -11,7 +11,7 @@
# norootforbuild
Name: perl-Bootloader
-Version: 0.4.27
+Version: 0.4.29
Release: 1
Requires: perl >= %{perl_version}
Requires: perl-gettext
@@ -66,6 +66,18 @@
/usr/lib/bootloader
%changelog
+* Tue Sep 18 2007 - aosthof(a)suse.de
+- Added more verbose logging to update-bootloader and
+ bootloader_entry to be able to better analyze occurring
+ problems (#309837)
+* Tue Sep 18 2007 - od(a)suse.de
+- Add comment for former default value only during update (related
+ to #309837, prevents accumulating wrong information that may be
+ used during a later update)
+- Version bump to 0.4.29
+* Tue Sep 18 2007 - aosthof(a)suse.de
+- Adapted timestamps for log files (#309837)
+- Version bump to 0.4.28
* Tue Sep 18 2007 - od(a)suse.de
- Add comment for former default value only if it does not yet
exist (#309837)
++++++ bootloader_entry ++++++
--- perl-Bootloader/bootloader_entry 2007-08-23 12:52:12.000000000 +0200
+++ /mounts/work_src_done/STABLE/perl-Bootloader/bootloader_entry 2007-09-18 21:00:22.000000000 +0200
@@ -57,6 +57,9 @@
# Wrapper for the update-bootloader function
function update_bootloader()
{
+ echo "bootloader_entry: This is (wrapper) function update_bootloader" >> \
+ /var/log/YaST2/perl-BL-standalone-log
+
[ -x /sbin/update-bootloader ] || return 0
/sbin/update-bootloader "$@"
}
@@ -67,6 +70,9 @@
##############################
function add_entry()
{
+ echo "bootloader_entry: This is function add_entry()" >> \
+ /var/log/YaST2/perl-BL-standalone-log
+
# Set up the new kernel
if [ -f /etc/sysconfig/bootloader ] &&
[ -f /boot/grub/menu.lst -o \
@@ -147,6 +153,8 @@
# sections at all, or do only chainload them (BootLILO.ycp), and
# thus do not match either. (#223030)
+ echo "bootloader_entry: This is function remove_entry()" >> \
+ /var/log/YaST2/perl-BL-standalone-log
if [ $flavor == "xen" ]; then
update_bootloader --image /boot/$image \
++++++ perl-Bootloader-0.4.27.tar.bz2 -> perl-Bootloader-0.4.29.tar.bz2 ++++++
--- perl-Bootloader/update-bootloader 2007-09-12 16:51:50.000000000 +0200
+++ /mounts/work_src_done/STABLE/perl-Bootloader/update-bootloader 2007-09-18 21:00:22.000000000 +0200
@@ -311,6 +311,10 @@
# execute selected operation
#
if (defined $oper{add}) {
+ open (LOG, ">>/var/log/YaST2/perl-BL-standalone-log");
+ print LOG ("update-bootloader: now executing operation add\n");
+ close LOG;
+
pod2usage("Please specify name and kernel image for new section")
unless $opt_name and $opt_image;
@@ -351,6 +355,10 @@
# Add original_name to params to be able to create comment line
push @params, original_name => "xen";
+ open (LOG, ">>/var/log/YaST2/perl-BL-standalone-log");
+ print LOG ("update-bootloader: calling Tools::AddSection (XEN)\n");
+ close LOG;
+
AddSection($opt_xen_name, @params);
}
# Add "normal" section
@@ -358,6 +366,10 @@
# Add original_name to params to be able to create comment line
push @params, original_name => "linux";
+ open (LOG, ">>/var/log/YaST2/perl-BL-standalone-log");
+ print LOG ("update-bootloader: calling Tools::AddSection (normal)\n");
+ close LOG;
+
AddSection($opt_name, @params);
}
@@ -377,6 +389,10 @@
# Add original_name to params to be able to create comment line
push @params, original_name => "failsafe";
+ open (LOG, ">>/var/log/YaST2/perl-BL-standalone-log");
+ print LOG ("update-bootloader: calling Tools::AddSection (failsafe)\n");
+ close LOG;
+
AddSection($opt_failsafe, @params);
}
}
@@ -391,12 +407,20 @@
push @params, initrd => $opt_initrd if $opt_initrd;
push @params, name => $opt_name if $opt_name;
+ open (LOG, ">>/var/log/YaST2/perl-BL-standalone-log");
+ print LOG ("update-bootloader: now executing operation remove\n");
+ close LOG;
+
my $num = CountSections(@params);
if ($num > 0) {
if ($num > 1 and not $opt_force) {
pod2usage("There is more than one section with image '$opt_image'");
} else {
+ open (LOG, ">>/var/log/YaST2/perl-BL-standalone-log");
+ print LOG ("update-bootloader: calling Tools::RemoveSections\n");
+ close LOG;
+
RemoveSections(@params);
}
} elsif (not $opt_force) {
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Remember to have fun...
---------------------------------------------------------------------
To unsubscribe, e-mail: opensuse-commit+unsubscribe(a)opensuse.org
For additional commands, e-mail: opensuse-commit+help(a)opensuse.org
diff -urN --exclude=CVS --exclude=.cvsignore --exclude=.svn --exclude=.svnignore old/perl-Bootloader-0.4.27/lib/Bootloader/Tools.pm new/perl-Bootloader-0.4.29/lib/Bootloader/Tools.pm
--- old/perl-Bootloader-0.4.27/lib/Bootloader/Tools.pm 2007-09-18 10:14:20.000000000 +0200
+++ new/perl-Bootloader-0.4.29/lib/Bootloader/Tools.pm 2007-09-18 20:39:36.000000000 +0200
@@ -113,11 +113,12 @@
print LOGFILE ("WARNING: Can't open $perl_logfile, using STDERR instead.\n");
}
- # the time should have been recorded when the action was taken... but this
- # is still useful as a hint
- my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime;
- my $timestamp = sprintf("%u-%02u-%02u %02u:%02u:%02u",
- $year + 1900, $mon + 1, $mday, $hour, $min, $sec);
+ # Adding timestamp to log messages
+ use POSIX qw(strftime);
+
+ sub timestamp () {
+ return strftime ( "%Y-%m-%d %H:%M:%S", localtime);
+ }
foreach my $rec (@{$lib_ref->GetLogRecords ()})
{
@@ -128,7 +129,7 @@
# Y2DEBUG has to be set ("export Y2DEBUG=1").
if ($level eq "debug" and defined $ENV{'Y2DEBUG'})
{
- print LOGFILE ("$timestamp DEBUG: $message\n");
+ print LOGFILE (timestamp() . " DEBUG: $message\n");
}
elsif ($level eq "debug" and not defined $ENV{'Y2DEBUG'})
{
@@ -136,35 +137,35 @@
}
elsif ($level eq "milestone")
{
- print LOGFILE ("$timestamp MILESTONE: $message\n");
+ print LOGFILE (timestamp() . " MILESTONE: $message\n");
}
elsif ($level eq "warning")
{
- print LOGFILE ("$timestamp WARNING: $message\n");
+ print LOGFILE (timestamp() . " WARNING: $message\n");
# If writing to perl logfile, also print warnings to STDERR
if ($using_logfile) {
- print STDERR ("$timestamp WARNING: $message\n");
+ print STDERR (timestamp() . " WARNING: $message\n");
}
}
elsif ($level eq "error")
{
- print LOGFILE ("$timestamp ERROR: $message\n");
+ print LOGFILE (timestamp() . " ERROR: $message\n");
# If writing to perl logfile, also print errors to STDERR
if ($using_logfile) {
- print STDERR ("ERROR: $message\n");
+ print STDERR (timestamp() . " ERROR: $message\n");
}
}
else
{
- print LOGFILE ("$timestamp ERROR: Uncomplete log record\n");
- print LOGFILE ("$timestamp ERROR: $message\n");
+ print LOGFILE (timestamp() . " ERROR: Uncomplete log record\n");
+ print LOGFILE (timestamp() . " ERROR: $message\n");
# If writing to perl logfile, also print errors to STDERR
if ($using_logfile) {
- print STDERR ("ERROR: Uncomplete log record\n");
- print STDERR ("ERROR: $message\n");
+ print STDERR (timestamp() . " ERROR: Uncomplete log record\n");
+ print STDERR (timestamp() . " ERROR: $message\n");
}
}
}
@@ -1603,9 +1604,14 @@
if ($default_removed) {
$glob_ref->{"default"} = $sections[0]{"name"};
- # If the default kernel is removed, add a comment to the globals so
- # yast2-bootloader is able to set the new default value appropriately.
- if (! defined $glob_ref->{"former_default_image_flavor"}) {
+ # During an update with YaST running in the inst-sys, if the default
+ # kernel is removed, add a comment to the globals so yast2-bootloader
+ # is able to set the new default value appropriately.
+ # Do not overwrite an old saved image flavor (e.g. when multiple
+ # kernels are updated during an update).
+ if (defined $ENV{'YAST_IS_RUNNING'} and
+ $ENV{'YAST_IS_RUNNING'} == "instsys" and
+ ! defined $glob_ref->{"former_default_image_flavor"}) {
my $former_flavor = $option{"image"};
$former_flavor =~ s/.*-(\w+)/\1/;
++++++ update-bootloader ++++++